@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from typing import Literal
 
 import astropy.units as u
 
@@ -9,5 +10,9 @@ class Encoder(ABC):
     Model: str
 
     @abstractmethod
-    def get_reading(self) -> u.Quantity:
+    def get_reading(self, axis: Literal["az", "el"]) -> u.Quantity:
+        ...
+
+    @abstractmethod
+    def finalize(self) -> None:
         ...
